@@ -3,11 +3,11 @@ package Analizo::Extractor::Doxyparse;
 use strict;
 use warnings;
 
-use base qw(Analizo::Extractor);
+use parent qw(Analizo::Extractor);
 
 use File::Temp qw/ tempfile /;
 use Cwd;
-use YAML;
+use YAML::XS;
 
 sub new {
   my ($package, @options) = @_;
