@@ -3,7 +3,7 @@ package Analizo::Extractor::Sloccount;
 use strict;
 use warnings;
 
-use base qw(Analizo::Extractor);
+use parent qw(Analizo::Extractor);
 
 use File::Path;
 use File::Spec;
